---
layout: "default"
title       : Identity Decentralized
description : "Resources for Creating a Vendor Agnostic, User-Controlled, Identity Layer for the Internet."
twitter:
  card      : "summary_large_image"
image       : "https://infominer.id/DIDecentralized/images/IDecentralized.png"
---

<center><img src="images/identity-decentralized.png"/></center>

# DID - Digital Identity Decentralized

>A good self‐sovereign identity system will allow individuals to directly influence how companies, governments, and others correlate our interactions across different services and locations by default. It won’t fix all identity problems nor preclude alternative identity approaches, but it will put the individual in control of most uses of identity and give organizations a simpler, easier, more ethical way to use identity to improve how they provide services and products. When successful, it will not only enable individuals to exercise greater control over how companies and governments keep track of us, it will also illuminate those situations where self‐sovereign identity is restricted, facilitating a conversation about when and where such limits are appropriate. [Joe Andrieu -A Technology‐Free Definition of Self‐Sovereign Identity](https://github.com/jandrieu/rebooting-the-web-of-trust-fall2016/blob/master/topics-and-advance-readings/a-technology-free-definition-of-self-sovereign-identity.pdf)

## Note:

I'm getting to know the minimal-mistakes theme over at [SourceCrypto](https://infominer.id/SourceCrypto). I've gone as far with this theme as it can take me, and don't want to mess with the structure of this theme any more until I get the hang of  [minimal-mistakes](https://mademistakes.com/work/minimal-mistakes-jekyll-theme/).

As you can see, I'm continually working to break up the info into separate files, so it can all grow :D

Submit any information you'd like included in this resource with an issue, or a pull-request.


[[**T**](#contents)]witter • [[**G**](#contents)]ithub • [[**B**](#contents)]log • [[**wp**](#contents)] whitepaper • [[**D**](#contents)]ocumentation • [[**F**](#contents)]orums • [[**C**](#contents)]hat • [[**tele**](#contents)]gram • [[**web**](#contents)]site
• [[**ϟ**](#contents)] related resource • [[**>**](#contents)] related section • [[**>>**](#contents)] another page on site. • [[**^**](#contents)] back to the contents.

## Contents
* [What is Decentralized ID?](#what-is-decentralized-id-)
* [What is Self Sovereign Identity?](#self-sovereign-identity-)
* [Directory](#directory-)
* [Sources](#sources-)
* [Tips Jar](#tips-jar-)

---

* [Edit this Page](https://github.com/infominer33/DIDecentralized)
* [infominer.id](https://infominer.id)

*Pull Requests Welcome*




![](https://i.imgur.com/9KpJRDr.png)


## What is Decentralized ID? [**^**](#contents)

That's a big question, and what follows are just some notes, until I work out a more thoughtful answer.

The essence of Decentralized-ID is in creating open standards for a privacy preserving internet-wide identity layer — not owned by any one particular organization, but interoperable between all.

It's impossible to have a conversation about decentralized-id without discussing blockchain and self sovereign identity: 
  * Self Sovereign Identity principles (with some help from the GDPR) have helped to shape the narrative around putting the identity owner in control over their personal information.
  * Excitement over Blockchain Tech has spilled over in support of longstanding efforts to create a privacy preserving internet-wide identity protocol, and inspired development of decentralized networks for online identification. 
  * The United Nations Sustainable Development Goals (SDGs) have also fueled efforts towards a global and widely accessible identity solution.



## Self Sovereign Identity [**^**](#contents)

![](https://imgur.com/3zz62kpl.png)


* [Christopher Allen](http://www.lifewithalacrity.com/)[[**info**](https://christophera.info/)] details the overarching history of internet idenitity standards and outlines [10 Principles of Self Sovereign Identity](https://github.com/WebOfTrustInfo/self-sovereign-identity/blob/master/self-sovereign-identity-principles.md) in his seminal work [The Path to Self-Soverereign Identity](http://www.lifewithalacrity.com/2016/04/the-path-to-self-soverereign-identity.html)[[**ϟ**](https://www.coindesk.com/path-self-sovereign-identity/amp/)]
* <a href="https://github.com/jandrieu/rebooting-the-web-of-trust-fall2016/raw/master/topics-and-advance-readings/a-technology-free-definition-of-self-sovereign-identity.pdf"><u>A Technlogy-Free Definition of Self-Sovereign Identity</u></a> is a continuation of the discussion started by Allen, offering 3 "Core Characteristics of Sovereign Identity".
* [7 Myths of Self Sovereign Identity](https://medium.com/evernym/7-myths-of-self-sovereign-identity-67aea7416b1)
* [Inevitable Rise of Self-Sovereign Identity](https://sovrin.org/wp-content/uploads/2018/03/The-Inevitable-Rise-of-Self-Sovereign-Identity.pdf)
* [SSIMeetup](http://ssimeetup.org/) [[**S**](https://www.slideshare.net/SSIMeetup/presentations)] [[**V**](https://www.youtube.com/channel/UCSqSTlKdbbCM1muGOhDa3Og)] [[**tele**](https://t.me/SSIMeetup)]
\- SSI Meetup is an open, collaborative community to help SSI evangelists around the world, independent of company interests or standards. 
* [SSI: A Roadmap for Adoption](https://github.com/WebOfTrustInfo/rebooting-the-web-of-trust-spring2018/blob/master/final-documents/a-roadmap-for-ssi.md)
* [Matching Identity Management Solutions to Self Sovereign Identity Solutions](https://www.slideshare.net/TommyKoens/matching-identity-management-solutions-to-selfsovereign-identity-principles)
<blockquote class="twitter-tweet" data-lang="en"><p lang="en" dir="ltr">0/ “Self-Sovereign Identity: A Progress Report”…</p>&mdash; Christopher Allen (@ChristopherA) <a href="https://twitter.com/ChristopherA/status/989120215702261761?ref_src=twsrc%5Etfw">April 25, 2018</a></blockquote>

* **[/DIDecentralized/self-sovereign-identity](self-sovereign-identity)** SSI documentation is still under development. This directory is to organize existing thought on SSI in one place for ease of study, and the development of new documentation.






## Directory [**^**](#contents)
To other pages within this repository.

  * [SSI\DID History](history.md) >>
    * [Losing Control over our Personal Information >>](history.md#losing-control-over-our-personal-information) '80s
    * [PGP - Web of Trust >>](#pgp---web-of-trust-) '91
    * [International Planetwork Conference >>](history.md#international-planetwork-conference-) '00s
    * [XNS Public Trust Organization >>](history.md#xns-public-trust-organization-)
    * [The Augmented Social Network >>](history.md#the-augmented-social-network-) '03
    * [IDCommons >>](history.md#idcommons-) '01
    * [Identity Gang >>](history.md#identity-gang-) '04
      * [Kim Cameron - Laws of Identity >>](history.md#kim-cameron---laws-of-identity) 
    * [Internet Identity Workshop—IIW >>](history.md#internet-identity-workshop-) '05
    * [W3C Credentials Community Group >>](history.md#w3c-credentials-community-group-) '14 
    * [Bitnation >>](history.md#bitnation-) '15
    * [The United Nations Sustainable Development Goals >>](history.md#the-united-nations-sustainable-development-goals-) '15
    * [history.md#Rebooting-Web-of-Trust (RWoT) >>](history.md#rebooting-the-web-of-trust-) 
    * [Evernym >>](history.md#evernym-)
    * [ID2020 and the GDPR >>](history.md#id2020-and-the-gdpr-) '16
    * [The End of 2016 >>](history.md#the-end-of-2016-)
    * [Decentralized Identity Foundation >>](history.md#decentralized-identity-foundation-) '17
    * [DID Standards History >>](history.md#standards-history-)
* [Self Sovereign Identity](self-sovereign-identity) >>
* [DID Related Web Standards](standards) >>
  * [XDI](standards/#xdi-) >>
    * [OASIS XDI TC Technical Committee on GitHub](standards/#oasis-xdi-tech-committee-on-github-) >>
  * [W3C](standards/#w3c-) >>
    * [DID the Decentralized Identifier](standards/#did-the-decentralized-identifier-) >>
    * [Verifiable Claims](standards/#verifiable-claims-) >>
  * [Decentralized Key Managment DKMS](standards/#decentralized-key-management-agents-) >>
  * [DID Auth](standards/#did-auth-) >>
  * [Blockcerts](standards/#blockcerts-) >>
  * [Schema](standards/#schema-) >>
* [DID Adoption](adoption.html) >>
* [GDPR](gdpr) >>
* [Humanitarian](humanitarian.md) >>
* [Identity Related GitHub Repositories](identity-github.md) >>
* [Literature](literature.md) >>
* [Rebooting Web of Trust](rebooting-web-of-trust.md) >>
* [Media](media.md) >> - Video, Podcasts and Slideshare  
* [Decentralized Identity Foundation—DIF](identity-foundation.md) >>
* [Bitcoin](bitcoin.md) >>
  * [Spidchain](bitcoin.md#spidchain-) >>
* [Ethereum](ethereum/) >>
  * [ERC-EIP](ethereum/#erc-eip-) >>
  * [ERC725-735](ethereum/erc725-735-)
  * [uPort](ethereum/#uport-) >>
  * [Jolocom](ethereum/#jolocom-) >>
  * [Spidchain](ethereum/#spidchain-) >>
  * [Cryptonomica](ethereum/cryptonomica.html) >>
  * [Assorted Ethereum Apps](ethereum/#assorted-ethereum-apps-) >>
* [Indy Ecosystem](indy-ecosystem/) >>
  * [Adoption](indy-ecosystem/adoption.md) >>
  * [Indy Github](indy-ecosystem/indy-github.md) >>
  * [Literature](indy-ecosystem/literature.md) >>
  * [Sovrin Foundation](indy-ecosystem/sovrin.foundation.md) >>
  * [VON](indy-ecosystem/VON.md) >>
* [Hyperledger Global Forum](hgf-2018/) >>
* [State Sponsored](state-sponsored.md) >>
* [Microsoft](microsoft.md) >>
* [IBM](ibm.md) >>



## Sources [**^**](#contents)
* [SSI Meetup](http://ssimeetup.org/) [[**V**](https://www.youtube.com/channel/UCSqSTlKdbbCM1muGOhDa3Og)][[**ϟ**](https://www.slideshare.net/SSIMeetup/presentations/)] 
* [IIW-Wiki](https://iiw.idcommons.net/Main_Page)
* [wiki.idcommons.net](http://wiki.idcommons.net/Main_Page)
* [/WebOfTrustInfo](https://github.com/WebOfTrustInfo/)
* [/peacekeeper/blockchain-identity](https://github.com/peacekeeper/blockchain-identity)
* [identitywoman.net](https://identitywoman.net/)
* [windley.com/tags/identity](http://www.windley.com/tags/identity.shtml)
* [Kim Camerons Identity Blog](https://identityblog.com)

---

## Tips Jar [**^**](#contents)

BTC— 1GvkjHtiy9LUjVkStnEAXxjhcoS56aCokY

![](https://imgur.com/yXLLm9Bl.png) 

DOGE— DSzMxfABB8EwKiumzV7YHhS7HTvWAyM7QF

![](https://i.imgur.com/0zBLoUP.png) 
